==> ivs-1.93.0-sources.jar: software/amazon/awscdk/services/ivs/PlaybackKeyPair.java <==
package software.amazon.awscdk.services.ivs;

/**
 * (experimental) A new IVS Playback Key Pair.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:21.822Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ivs.$Module.class, fqn = "@aws-cdk/aws-ivs.PlaybackKeyPair")
public class PlaybackKeyPair extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.ivs.IPlaybackKeyPair {

    protected PlaybackKeyPair(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PlaybackKeyPair(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PlaybackKeyPair(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ivs.PlaybackKeyPairProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) Key-pair ARN.
     * <p>
     * For example: arn:aws:ivs:us-west-2:693991300569:playback-key/f99cde61-c2b0-4df3-8941-ca7d38acca1a
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getPlaybackKeyPairArn() {
        return software.amazon.jsii.Kernel.get(this, "playbackKeyPairArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Key-pair identifier.
     * <p>
     * For example: 98:0d:1a:a0:19:96:1e:ea:0a:0a:2c:9a:42:19:2b:e7
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getPlaybackKeyPairFingerprint() {
        return software.amazon.jsii.Kernel.get(this, "playbackKeyPairFingerprint", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link software.amazon.awscdk.services.ivs.PlaybackKeyPair}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ivs.PlaybackKeyPair> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.ivs.PlaybackKeyPairProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.ivs.PlaybackKeyPairProps.Builder();
        }

        /**
         * (experimental) The public portion of a customer-generated key pair.
         * <p>
         * @return {@code this}
         * @param publicKeyMaterial The public portion of a customer-generated key pair. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder publicKeyMaterial(final java.lang.String publicKeyMaterial) {
            this.props.publicKeyMaterial(publicKeyMaterial);
            return this;
        }

        /**
         * (experimental) An arbitrary string (a nickname) assigned to a playback key pair that helps the customer identify that resource.
         * <p>
         * The value does not need to be unique.
         * <p>
         * Default: None
         * <p>
         * @return {@code this}
         * @param name An arbitrary string (a nickname) assigned to a playback key pair that helps the customer identify that resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(final java.lang.String name) {
            this.props.name(name);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ivs.PlaybackKeyPair}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.ivs.PlaybackKeyPair build() {
            return new software.amazon.awscdk.services.ivs.PlaybackKeyPair(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> ivs-1.182.0-sources.jar: software/amazon/awscdk/services/ivs/PlaybackKeyPair.java <==
package software.amazon.awscdk.services.ivs;

/**
 * (experimental) A new IVS Playback Key Pair.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * PlaybackKeyPair keyPair = PlaybackKeyPair.Builder.create(this, "PlaybackKeyPair")
 *         .publicKeyMaterial(myPublicKeyPemString)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:36.408Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ivs.$Module.class, fqn = "@aws-cdk/aws-ivs.PlaybackKeyPair")
public class PlaybackKeyPair extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.ivs.IPlaybackKeyPair {

    protected PlaybackKeyPair(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PlaybackKeyPair(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PlaybackKeyPair(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ivs.PlaybackKeyPairProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) Key-pair ARN.
     * <p>
     * For example: arn:aws:ivs:us-west-2:693991300569:playback-key/f99cde61-c2b0-4df3-8941-ca7d38acca1a
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getPlaybackKeyPairArn() {
        return software.amazon.jsii.Kernel.get(this, "playbackKeyPairArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Key-pair identifier.
     * <p>
     * For example: 98:0d:1a:a0:19:96:1e:ea:0a:0a:2c:9a:42:19:2b:e7
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getPlaybackKeyPairFingerprint() {
        return software.amazon.jsii.Kernel.get(this, "playbackKeyPairFingerprint", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link software.amazon.awscdk.services.ivs.PlaybackKeyPair}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ivs.PlaybackKeyPair> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.ivs.PlaybackKeyPairProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.ivs.PlaybackKeyPairProps.Builder();
        }

        /**
         * (experimental) The public portion of a customer-generated key pair.
         * <p>
         * @return {@code this}
         * @param publicKeyMaterial The public portion of a customer-generated key pair. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder publicKeyMaterial(final java.lang.String publicKeyMaterial) {
            this.props.publicKeyMaterial(publicKeyMaterial);
            return this;
        }

        /**
         * (experimental) An arbitrary string (a nickname) assigned to a playback key pair that helps the customer identify that resource.
         * <p>
         * The value does not need to be unique.
         * <p>
         * Default: None
         * <p>
         * @return {@code this}
         * @param name An arbitrary string (a nickname) assigned to a playback key pair that helps the customer identify that resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(final java.lang.String name) {
            this.props.name(name);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ivs.PlaybackKeyPair}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.ivs.PlaybackKeyPair build() {
            return new software.amazon.awscdk.services.ivs.PlaybackKeyPair(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
